<?php

declare(strict_types=1);

namespace FiloBlu\GcpLogging\Helper;

use Magento\Framework\App\Helper\AbstractHelper;
use Magento\Store\Model\ScopeInterface;

/**
 *
 */
class Data extends AbstractHelper
{
    const GCP_LOGGING_ENABLED_PATH = 'filoblu_gcp_logging/general/filoblu_gcp_logging_enabled';

    const GCP_LOGGING_TYPE_PATH = 'filoblu_gcp_logging/general/filoblu_gcp_logging_type';

    const GCP_LOGGING_FILE_NAME_PATH = 'filoblu_gcp_logging/general/filoblu_gcp_logging_file_name';

    const GCP_LOGGING_PROJECT_ID_PATH = 'filoblu_gcp_logging/general/filoblu_gcp_logging_project_id';

    const GCP_LOGGING_KEY_FILE_PATH = 'filoblu_gcp_logging/general/filoblu_gcp_logging_key_file';

    const LOG_TYPE_GCP = 'gcp';

    const LOG_TYPE_FILE = 'file';

    const ADMIN_URL = 'admin/url/custom';


    /**
     * @return bool
     */
    public function gcpLoggingIsEnabled()
    {
        return $this->scopeConfig->isSetFlag(self::GCP_LOGGING_ENABLED_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return string
     */
    public function getGcpLoggingType()
    {
        $type = $this->scopeConfig->getValue(self::GCP_LOGGING_TYPE_PATH, ScopeInterface::SCOPE_STORE);

        switch($type)
        {
            case 'gcp':
            /** @noinspection ClassConstantCanBeUsedInspection */
            case 'FiloBlu\GcpLogging\Logger\Handler\Gcp':
                return self::LOG_TYPE_GCP;

            default:
            case 'file':
            case 'FiloBlu\GcpLogging\Logger\Handler\File':
              return self::LOG_TYPE_FILE;
        }
    }

    /**
     * @return mixed
     */
    public function getLogFileName()
    {
        return $this->scopeConfig->getValue(self::GCP_LOGGING_FILE_NAME_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return array
     */
    public function getLoggingClientConfiguration()
    {
        $loggingClientConfiguration = [];
        $projectId = $this->getProjectId();
        if ($projectId) {
            $loggingClientConfiguration['projectId'] = $projectId;
        }

        $key = $this->getKey();

        if ($key) {
            $keyFile = json_decode($this->getKey(), true);
            if (!empty($keyFile)) {
                $loggingClientConfiguration['keyFile'] = $keyFile;
            }
        }

        return $loggingClientConfiguration;
    }

    /**
     * @return mixed
     */
    public function getProjectId()
    {
        return $this->scopeConfig->getValue(self::GCP_LOGGING_PROJECT_ID_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return mixed
     */
    public function getKey()
    {
        return $this->scopeConfig->getValue(self::GCP_LOGGING_KEY_FILE_PATH, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return mixed
     */
    public function getBackEndUrl()
    {
        return $this->scopeConfig->getValue(self::ADMIN_URL, ScopeInterface::SCOPE_STORE);
    }

    /**
     * @return string
     */
    public function moduleName()
    {
        return $this->_getModuleName();
    }
}
